---
name: Question
about: Ask a question (and help us improve our documentation)
title: 'Question: '
labels: 'question'
assignees: ''

---

Describe the problem or ask the question
========================================
A clear and concise description of what the problem or question is.

Provide an example, if applicable
---------------------------------
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See behaviour

Expectations
------------
A clear and concise description of what you expected (or wanted) to happen.

Screenshots
-----------
If applicable, add screenshots to help explain your question.

Computer
--------
Please complete the following information:
* OS: (e.g., iOS)
* Python version: (e.g., 3.6)
* Compiler with version: (e.g., gfortran 22)
* Apexpy version/branch: (e.g., 1.1.0/main)

Additional context
------------------
Add any other context about the problem here.
